==> monocdk-nag-0.0.45.tar.gz: package/lib/AwsSolutions/aws-solutions.d.ts <==
import { IConstruct } from 'monocdk';
import { NagPack } from '../common';
/**
 * Check Best practices based on AWS Solutions Security Matrix.
 *
 * @stability stable
 */
export declare class AwsSolutionsChecks extends NagPack {
    /**
     * All aspects can visit an IConstruct.
     *
     * @stability stable
     */
    visit(node: IConstruct): void;
    /**
     * Check Compute Services
     * @param node the IConstruct to evaluate
     * @param ignores list of ignores for the resource
     */
    private checkCompute;
    /**
     * Check Storage Services
     * @param node the IConstruct to evaluate
     * @param ignores list of ignores for the resource
     */
    private checkStorage;
    /**
     * Check Database Services
     * @param node the IConstruct to evaluate
     * @param ignores list of ignores for the resource
     */
    private checkDatabases;
    /**
     * Check Network and Delivery Services
     * @param node the IConstruct to evaluate
     * @param ignores list of ignores for the resource
     */
    private checkNetworkDelivery;
    /**
     * Check Management and Governance Services
     * @param node the IConstruct to evaluate
     * @param ignores list of ignores for the resource
     */
    private checkManagementGovernance;
    /**
     * Check Machine Learning Services
     * @param node the IConstruct to evaluate
     * @param ignores list of ignores for the resource
     */
    private checkMachineLearning;
    /**
     * Check Analytics Services
     * @param node the IConstruct to evaluate
     * @param ignores list of ignores for the resource
     */
    private checkAnalytics;
    /**
     * Check Security and Compliance Services
     * @param node the IConstruct to evaluate
     * @param ignores list of ignores for the resource
     */
    private checkSecurityCompliance;
    /**
     * Check Serverless Services
     * @param node the IConstruct to evaluate
     * @param ignores list of ignores for the resource
     */
    private checkServerless;
    /**
     * Check Application Integration Services
     * @param node the IConstruct to evaluate
     * @param ignores list of ignores for the resource
     */
    private checkApplicationIntegration;
    /**
     * Check Media Services
     * @param node the IConstruct to evaluate
     * @param ignores list of ignores for the resource
     */
    private checkMediaServices;
    /**
     * Check Developer Tools Services
     * @param node the IConstruct to evaluate
     * @param ignores list of ignores for the resource
     */
    private checkDeveloperTools;
}

==> monocdk-nag-0.0.125.tar.gz: package/lib/AwsSolutions/aws-solutions.d.ts <==
import { IConstruct } from 'monocdk';
import { NagPack } from '../common';
/**
 * Check Best practices based on AWS Solutions Security Matrix.
 *
 * @stability stable
 */
export declare class AwsSolutionsChecks extends NagPack {
    /**
     * All aspects can visit an IConstruct.
     *
     * @stability stable
     */
    visit(node: IConstruct): void;
    /**
     * Check Compute Services
     * @param node the CfnResource to check
     * @param ignores list of ignores for the resource
     */
    private checkCompute;
    /**
     * Check Storage Services
     * @param node the CfnResource to check
     * @param ignores list of ignores for the resource
     */
    private checkStorage;
    /**
     * Check Database Services
     * @param node the CfnResource to check
     * @param ignores list of ignores for the resource
     */
    private checkDatabases;
    /**
     * Check Network and Delivery Services
     * @param node the CfnResource to check
     * @param ignores list of ignores for the resource
     */
    private checkNetworkDelivery;
    /**
     * Check Management and Governance Services
     * @param node the CfnResource to check
     * @param ignores list of ignores for the resource
     */
    private checkManagementGovernance;
    /**
     * Check Machine Learning Services
     * @param node the CfnResource to check
     * @param ignores list of ignores for the resource
     */
    private checkMachineLearning;
    /**
     * Check Analytics Services
     * @param node the CfnResource to check
     * @param ignores list of ignores for the resource
     */
    private checkAnalytics;
    /**
     * Check Security and Compliance Services
     * @param node the CfnResource to check
     * @param ignores list of ignores for the resource
     */
    private checkSecurityCompliance;
    /**
     * Check Serverless Services
     * @param node the CfnResource to check
     * @param ignores list of ignores for the resource
     */
    private checkServerless;
    /**
     * Check Application Integration Services
     * @param node the CfnResource to check
     * @param ignores list of ignores for the resource
     */
    private checkApplicationIntegration;
    /**
     * Check Media Services
     * @param node the CfnResource to check
     * @param ignores list of ignores for the resource
     */
    private checkMediaServices;
    /**
     * Check Developer Tools Services
     * @param node the CfnResource to check
     * @param ignores list of ignores for the resource
     */
    private checkDeveloperTools;
}
